@@ -1,6 +1,7 @@
 package Pcore::App::Sphinx;
 
 use Pcore -class;
+use Pcore::Sphinx;
 
 extends qw[Pcore::App::Alien];
 
@@ -21,33 +22,31 @@ our $CFG = {
 };
 
 # CLI
-sub cli_name ($self) {
-    return 'sphinx';
-}
+around CLI => sub ( $orig, $self ) {
+    my $cli = $self->$orig;
 
-around cli_opt => sub ( $orig, $self ) {
-    my $opt = $self->$orig;
+    $cli->{name} = 'sphinx';
 
-    $opt->{r2_system} = {
+    $cli->{opt}->{r2_system} = {
         short => undef,
         desc  => q[install re2 to /usr/local instead of sphinx app. directory],
     };
 
-    $opt->{indexer} = {
+    $cli->{opt}->{indexer} = {
         short => undef,
         desc  => q[],
     };
 
-    return $opt;
+    return $cli;
 };
 
 sub _build_sphinx_ver ($self) {
-    return $self->cfg->{SPHINX}->{SPHINX_VER} || $ENV->{CFG}->{SPHINX}->{SPHINX_VER};
+    return $self->cfg->{SPHINX}->{SPHINX_VER} || $ENV->get_dist('pcore-sphinx')->cfg->{SPHINX}->{SPHINX_VER};
 }
 
 # APP
 around run => sub ( $orig, $self ) {
-    if ( $ARGV{opt}->{indexer} ) {
+    if ( $ENV->cli->{opt}->{indexer} ) {
         say q[start indexer];
 
         $self->generate_alien_cfg;
@@ -191,7 +190,7 @@ around app_build => sub ( $orig, $self ) {
         my $res = try {
 
             # re2
-            my $re2_prefix = ( $ARGV{opt}->{r2_system} ? q[/usr/local/] : $self->alien_dir ) . 're2/';
+            my $re2_prefix = ( $ENV->cli->{opt}->{r2_system} ? q[/usr/local/] : $self->alien_dir ) . 're2/';
             P->file->rmtree($re2_prefix);
             P->file->mkpath($re2_prefix);
 
